from random import shuffle
from pool import Pool
import time

import poolGenerator
class Team():
    def __init__(self, region, players, startersPerFormat, tiers):
        self.region = region
        self.players = {}
        i = 0
        for f in range(len(tiers)):
            tierTeam = []
            for _ in range(startersPerFormat[f]):
                tierTeam.append(players[i])
                i += 1
            self.players[tiers[f]] = TierTeam(tierTeam)

class TierTeam():
    def __init__(self, players):
        self.players = players
        shuffle(players)
        self.count = 0

    def nextPlayer(self):
        self.count+=1
        return self.players[self.count - 1]
    
def monotier(filename, poolSize):
    start = time.time()
    teams = []
    file = open(filename, 'r')
    lines = file.readlines()
    tier = lines[0].replace("\n", "")
    for line in lines[1:]:
        items = line.replace("\n", "").split(": ")
        players = items[1].split(", ")
        teams.append(Team(items[0], players, [len(players)], [tier]))
    shuffle(teams)

    startersPerTeam = len(teams[0].players[tier].players)
    for team in teams:
        if len(team.players[tier].players) != startersPerTeam:
            print("Expected {} starters for team {} but only found {}.".format(startersPerTeam, team.region, len(team.players)) )
            return

    pools = poolGenerator.monotier(startersPerTeam, poolSize, len(teams), tier)

    filledPools = []
    for pool in pools:
        filledPool = Pool(pool.id, pool.tier)
        for team in pool.players:
            filledPool.addPlayer(teams[team].players[pool.tier].nextPlayer())
        filledPools.append(filledPool)
    end = time.time()
    print("Calculation time : {} seconds".format(end - start))
    return filledPools

def multitier(filename, poolSize):
    start = time.time()
    teams = []
    file = open(filename, 'r')
    lines = file.readlines()
    startersPerFormat = []
    tiers = []
    for string in lines[0].split(", "):
        tierAndNumber = string.split(": ")
        tiers.append(tierAndNumber[0])
        startersPerFormat.append(int(tierAndNumber[1]))
    for line in lines[1:]:
        items = line.replace("\n", "").split(": ")
        players = items[1].split(", ")
        teams.append(Team(items[0], players, startersPerFormat, tiers))
    shuffle(teams)

    pools = poolGenerator.multiTiers(startersPerFormat, poolSize, len(teams), tiers)

    filledPools = []
    for pool in pools:
        filledPool = Pool(pool.id, pool.tier)
        for team in pool.players:
            filledPool.addPlayer(teams[team].players[pool.tier].nextPlayer())
        filledPools.append(filledPool)
    end = time.time()
    print("Calculation time : {} seconds".format(end - start))
    return filledPools

def printPools(pools, output):
    file = open(output, 'w')
    file.write('[SPOILER="Groups"]\n')
    for pool in pools:
        file.write(str(pool))
    file.write('[/SPOILER]\n\n[SPOILER="Individual Matchups "]')
    for pool in pools:
        file.write("\n" + pool.toString())
    file.write('[/SPOILER]')

if __name__ == "__main__":
    ##printPools(monotier("zuwc.txt", 4), "zuwc_results.txt")
    printPools(multitier("wcop.txt", 4), "wcop_results.txt")